@@ -9,7 +9,7 @@ import (
 	"github.com/99designs/aws-vault/v7/prompt"
 	"github.com/99designs/aws-vault/v7/vault"
 	"github.com/99designs/keyring"
-	"github.com/alecthomas/kingpin"
+	"github.com/alecthomas/kingpin/v2"
 	isatty "github.com/mattn/go-isatty"
 	"golang.org/x/term"
 )
